@@ -60,10 +60,6 @@
 //!     fn collect(&self)  -> Result<(), &'static str> {
 //!         Ok(())
 //!     }
-//! 
-//!     fn clean(&self) -> Result<(), &'static str> {
-//!         Ok(())
-//!     }
 //! }
 //!
 //! // This is a direct copy of the implementation of ExampleAgent1
@@ -81,10 +77,6 @@
 //!     fn collect(&self)  -> Result<(), &'static str> {
 //!         Ok(())
 //!     }
-//!
-//!     fn clean(&self) -> Result<(), &'static str> {
-//!         Ok(())
-//!     }
 //! }
 //!```
 
@@ -124,11 +116,6 @@ pub fn tick_collect(environment: &mut Box<dyn Environment>) -> Result<(), &'stat
     Ok(())
 }
 
-pub fn clean(environment: &mut Box<dyn Environment>) -> Result<(), &'static str> {
-    environment.clean()?;
-    Ok(())
-}
-
 /// Applies a collect to a passed in environment. This takes both
 /// the default environment provided by this library and custom
 /// defined environments created by the user.
@@ -226,13 +213,6 @@ impl Environment for DefaultEnvironment {
         Ok(())
     }
 
-    fn clean(&self) -> Result<(), &'static str> {
-        for agent in &self.population {
-            agent.to_owned().clean()?;
-        }
-        Ok(())
-    }
-
     fn add_agent(&mut self, agent: Box<dyn Agent>) -> Result<(), &'static str> {
         self.population.push(agent);
         Ok(())
